<template>
  <NutForm
    :model-value="form"
    ref="formRef"
    :rules="rules"
    label-position="top"
    class="order-bill-recharge phone chunk-form"
  >
    <NutFormItem label="姓名" class="bole-form-item" prop="name" required>
      <NutInput
        v-model.trim="form.name"
        class="bole-input-text"
        placeholder="请填写您的姓名"
        type="text"
      />
    </NutFormItem>
    <NutFormItem label="联系方式" class="bole-form-item" prop="phoneNumber" required>
      <NutInput
        v-model.trim="form.phoneNumber"
        class="bole-input-text"
        placeholder="请填写您的联系方式"
        type="text"
      />
    </NutFormItem>
  </NutForm>
</template>

<script setup lang="ts">
import { Form as NutForm, FormItem as NutFormItem, Input as NutInput } from '@nutui/nutui-taro';
import { FormRules } from '@nutui/nutui-taro/dist/types/__VUE/form/types';
import { reactive, ref } from 'vue';
import { CreateOrUpdatePromoterInput, useLifeRechargeContext } from '@life-payment/core-vue';
import { FormValidator } from '../../utils';

defineOptions({
  name: 'GeneratePromotionCodeView',
});

const emit = defineEmits<{
  (e: 'submit', data: string): void;
}>();

const form = reactive({
  name: '',
  phoneNumber: '',
});

const rules = reactive<FormRules>({
  name: [{ required: true, message: '请填写您的姓名' }],
  phoneNumber: [
    { required: true, message: '请填写您的联系方式' },
    { validator: FormValidator.validatorPhoneNumber, message: '请输入正确的手机号' },
  ],
});

const { blLifeRecharge } = useLifeRechargeContext();

const formRef = ref<any>(null);

function handleSubmit() {
  if (!formRef.value) return;
  formRef.value.validate().then(({ valid, errors }: any) => {
    if (valid) {
      createOrUpdatePromoter();
    }
  });
}

async function createOrUpdatePromoter() {
  try {
    let params: CreateOrUpdatePromoterInput = {
      userId: blLifeRecharge.accountModel.userId,
      name: form.name,
      phoneNumber: form.phoneNumber,
    };
    let res = await blLifeRecharge.services.createOrUpdatePromoter(params);
    if (res) {
      if (params.phoneNumber === blLifeRecharge.accountModel.phoneNumber) {
        blLifeRecharge.accountModel.setUserPromoterIdNumber(res);
      }
      emit('submit', res);
    }
  } catch (error) {}
}

defineExpose({
  handleSubmit,
});
</script>
